OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

# Descargar e imprimir el informe

Le recomendamos que tenga una versión impresa y actualizada de su evaluación de riesgos (informe) disponible en su empresa !

Informe

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Plan de acción

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Resumen de riesgos

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Resumen de medidas

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More